@@ -1,3 +1,5 @@
+import json
+import base64
 from functools import cached_property
 
 from django.db import models
@@ -38,5 +40,22 @@ class ShopBase(models.Model):
     def update_webhooks(self):
         update_shop_webhooks(self)
 
+    def graph(self, operation_name, variables, operations_document):
+
+        with self.shopify_session:
+            result = shopify.GraphQL().execute(
+                query=operations_document,
+                variables=variables,
+                operation_name=operation_name,
+            )
+
+        result = json.loads(result)
+        return result
+
+    @cached_property
+    def host(self):
+        admin_url = f'{self.shopify_domain}/admin'
+        return base64.b64encode(admin_url.encode()).decode()
+
     class Meta:
         abstract = True
